@@ -7,6 +7,7 @@ import webbrowser
 import threading
 import subprocess
 import re
+import time
 import urllib.parse
 from gi.repository.GdkPixbuf import Pixbuf
 from enum import Enum
@@ -19,7 +20,6 @@ from minigalaxy.launcher import start_game, config_game
 from minigalaxy.installer import uninstall_game, install_game
 from minigalaxy.css import CSS_PROVIDER
 from minigalaxy.paths import ICON_WINE_PATH
-from minigalaxy.paths import ICON_UPDATE_PATH
 from minigalaxy.api import NoDownloadLinkFound
 
 
@@ -72,7 +72,8 @@ class GameTile(Gtk.Box):
             os.makedirs(CACHE_DIR, mode=0o755)
 
         self.reload_state()
-        self.load_thumbnail()
+        load_thumbnail_thread = threading.Thread(target=self.load_thumbnail)
+        load_thumbnail_thread.start()
 
         # Start download if Minigalaxy was closed while downloading this game
         self.resume_download_if_expected()
@@ -83,8 +84,8 @@ class GameTile(Gtk.Box):
             self.wine_icon.set_from_file(ICON_WINE_PATH)
             self.wine_icon.show()
 
-        if not self.game.url:
-            self.menu_button_store.hide()
+        store_button_thread = threading.Thread(target=self.__show_store_button_when_url_ready)
+        store_button_thread.start()
 
     # Downloads if Minigalaxy was closed with this game downloading
     def resume_download_if_expected(self):
@@ -165,33 +166,39 @@ class GameTile(Gtk.Box):
         download_thread.start()
 
     def load_thumbnail(self):
-        if self.__set_image():
-            return True
-        if not self.game.image_url or not self.game.id:
-            return False
+        set_result = self.__set_image()
+        if not set_result:
+            tries = 10
+            performed_try = 0
+            while performed_try < tries:
+                if self.game.image_url and self.game.id:
+                    # Download the thumbnail
+                    image_url = "https:{}_196.jpg".format(self.game.image_url)
+                    thumbnail = os.path.join(THUMBNAIL_DIR, "{}.jpg".format(self.game.id))
 
-        # Download the thumbnail
-        image_url = "https:{}_196.jpg".format(self.game.image_url)
-        thumbnail = os.path.join(THUMBNAIL_DIR, "{}.jpg".format(self.game.id))
-
-        download = Download(image_url, thumbnail, finish_func=self.__set_image)
-        DownloadManager.download_now(download)
-        return True
+                    download = Download(image_url, thumbnail, finish_func=self.__set_image)
+                    DownloadManager.download_now(download)
+                    set_result = True
+                    break
+                performed_try += 1
+                time.sleep(1)
+        return set_result
 
     def __set_image(self):
+        set_result = False
         self.game.set_install_dir()
         thumbnail_install_dir = os.path.join(self.game.install_dir, "thumbnail.jpg")
         thumbnail_cache_dir = os.path.join(THUMBNAIL_DIR, "{}.jpg".format(self.game.id))
         if os.path.isfile(thumbnail_install_dir):
             GLib.idle_add(self.image.set_from_file, thumbnail_install_dir)
-            return True
+            set_result = True
         elif os.path.isfile(thumbnail_cache_dir):
             GLib.idle_add(self.image.set_from_file, thumbnail_cache_dir)
             # Copy image to
             if os.path.isdir(os.path.dirname(thumbnail_install_dir)):
                 shutil.copy2(thumbnail_cache_dir, thumbnail_install_dir)
-            return True
-        return False
+            set_result = True
+        return set_result
 
     def get_keep_executable_path(self):
         keep_path = ""
@@ -292,7 +299,7 @@ class GameTile(Gtk.Box):
             GLib.idle_add(self.update_to_state, success_state)
             install_success = True
             if dlc_title:
-                self.game.set_dlc_info("version", self.api.get_version(self.game, dlc_title=dlc_title), dlc_title)
+                self.game.set_dlc_info("version", self.api.get_version(self.game, dlc_name=dlc_title), dlc_title)
             else:
                 self.game.set_info("version", self.api.get_version(self.game))
         else:
@@ -367,8 +374,9 @@ class GameTile(Gtk.Box):
     def update_gtk_box_for_dlc(self, icon, title, installer):
         if title not in self.dlc_dict:
             dlc_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
+            dlc_box.set_spacing(8)
             image = Gtk.Image()
-            image.set_from_icon_name("gtk-cdrom", 1)
+            image.set_from_icon_name("media-optical", Gtk.IconSize.BUTTON)
             dlc_box.pack_start(image, False, True, 0)
             label = Gtk.Label(label=title, xalign=0)
             dlc_box.pack_start(label, True, True, 0)
@@ -380,20 +388,17 @@ class GameTile(Gtk.Box):
             dlc_box.show_all()
             self.get_async_image_dlc_icon(icon, title)
         download_info = self.api.get_download_info(self.game, dlc_installers=installer)
-        if self.game.is_installed(dlc_title=title):
-            icon_name = "gtk-ok"
-            self.dlc_dict[title][0].set_sensitive(False)
-        elif self.game.is_update_available(version_from_api=download_info["version"], dlc_title=title):
-            icon_name = ICON_UPDATE_PATH
+        if self.game.is_update_available(version_from_api=download_info["version"], dlc_title=title):
+            icon_name = "emblem-synchronizing"
             self.dlc_dict[title][0].set_sensitive(True)
+        elif self.game.is_installed(dlc_title=title):
+            icon_name = "object-select"
+            self.dlc_dict[title][0].set_sensitive(False)
         else:
-            icon_name = "gtk-goto-bottom"
+            icon_name = "document-save"
             self.dlc_dict[title][0].set_sensitive(True)
         install_button_image = Gtk.Image()
-        if icon_name in [ICON_UPDATE_PATH]:
-            install_button_image.set_from_file(ICON_UPDATE_PATH)
-        else:
-            install_button_image.set_from_icon_name(icon_name, 1)
+        install_button_image.set_from_icon_name(icon_name, Gtk.IconSize.BUTTON)
         self.dlc_dict[title][0].set_image(install_button_image)
 
     def get_async_image_dlc_icon(self, icon, title):
@@ -428,6 +433,17 @@ class GameTile(Gtk.Box):
         self.set_center_widget(self.progress_bar)
         self.progress_bar.set_fraction(0.0)
 
+    def __show_store_button_when_url_ready(self):
+        tries = 10
+        performed_try = 0
+        GLib.idle_add(self.menu_button_store.hide)
+        while performed_try < tries:
+            if self.game.url:
+                GLib.idle_add(self.menu_button_store.show)
+                break
+            performed_try += 1
+            time.sleep(1)
+
     def reload_state(self):
         self.game.set_install_dir()
         dont_act_in_states = [self.state.QUEUED, self.state.DOWNLOADING, self.state.INSTALLING, self.state.UNINSTALLING,
@@ -532,7 +548,7 @@ class GameTile(Gtk.Box):
 
         elif state == self.state.UPDATABLE:
             self.update_icon.show()
-            self.update_icon.set_from_file(ICON_UPDATE_PATH)
+            self.update_icon.set_from_icon_name("emblem-synchronizing", Gtk.IconSize.LARGE_TOOLBAR)
             self.button.set_label(_("play"))
             self.menu_button.show()
             tooltip_text = "{} (update{})".format(self.game.name, ", Wine" if self.game.platform == "windows" else "")
